package it.macke.android;

import java.util.HashMap;
import java.util.Map;

import android.accounts.Account;
import android.accounts.AccountManager;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.ContentValues;
import android.content.DialogInterface;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.Spinner;

public class AddLocalCalendarActivity extends Activity implements OnClickListener
{
	protected Uri baseUri = Uri.parse("content://com.android.calendar/calendars");

	protected Button createCalendar;
	protected Spinner accountList;
	protected Map<String, Account> accounts;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		createCalendar = (Button) findViewById(R.id.createCalendar);
		accountList = (Spinner) findViewById(R.id.accountName);

		readAccounts();
		fillSpinner();

		createCalendar.setOnClickListener(this);

	}

	private void readAccounts()
	{
		accounts = new HashMap<String, Account>();
		Account[] readAccounts = AccountManager.get(this).getAccounts();
		for (Account a : readAccounts)
		{
			accounts.put(a.name, a);
		}
		if (readAccounts.length == 0)
		{
			showDialog("No accounts found", "You need to set up a (Google) account.");
			createCalendar.setEnabled(false);
		}
	}

	private void fillSpinner()
	{
		ArrayAdapter<String> adapterForSpinner = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item);
		adapterForSpinner.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		accountList.setAdapter(adapterForSpinner);
		for (String a : accounts.keySet())
		{
			adapterForSpinner.add(a);
		}
	}

	private void addLocalCalendar(Account account)
	{
		Uri calUri = createCompleteUri();

		ContentValues vals = new ContentValues();
		vals.put("_id", 1);
		vals.put("_sync_account", account.name);
		vals.put("_sync_account_type", account.type);
		vals.put("name", account.name);
		vals.put("displayName", account.name);
		vals.put("color", 14417920);
		vals.put("access_level", 700);
		vals.put("selected", 1);
		vals.put("ownerAccount", account.name);
		vals.put("sync_events", 1);
		vals.put("timezone", "GMT");
		vals.put("hidden", 0);

		getContentResolver().insert(calUri, vals);
		showDialog("Calendar created", account.name);
	}

	private Uri createCompleteUri()
	{
		Uri.Builder b = baseUri.buildUpon();
		b.appendQueryParameter("caller_is_syncadapter", "true");
		b.appendQueryParameter("account_name", "Lokal");
		b.appendQueryParameter("account_type", "LOCAL");
		Uri calUri = b.build();
		Log.d("completeUri", calUri.toString());
		return calUri;
	}

	public void onClick(View view)
	{
		try
		{
			checkExistingCalendars();
			String accountName = (String) accountList.getSelectedItem();
			Account selectedAccount = accounts.get(accountName);
			addLocalCalendar(selectedAccount);
		}
		catch (Exception e)
		{
			Log.e("onClick", e.getMessage());
			e.printStackTrace();
			showDialog("Error while creating calendar", e.getMessage());
		}
	}

	private void showDialog(String title, String message)
	{
		AlertDialog.Builder builder = new AlertDialog.Builder(this);
		builder.setMessage(message).setTitle(title).setCancelable(false).setPositiveButton("OK", new DialogInterface.OnClickListener()
		{
			public void onClick(DialogInterface dialog, int id)
			{}
		});
		AlertDialog alert = builder.create();
		alert.show();
	}

	private void checkExistingCalendars() throws Exception
	{
		Cursor res = getContentResolver().query(baseUri, null, null, null, null);
		if (res.getCount() > 0)
		{
			throw new Exception("Please empty all calendar data.");
		}
	}
}